@@ -1,6 +1,7 @@
 from cyberfusion.CoreApiClient import models
 from typing import Optional, Union
 
+from cyberfusion.CoreApiClient._helpers import construct_includes_query_parameter
 from cyberfusion.CoreApiClient.http import DtoResponse
 from cyberfusion.CoreApiClient.interfaces import Resource
 
@@ -25,6 +26,7 @@ class CMSes(Resource):
         page: int = 1,
         per_page: int = 0,
         include_filters: models.CmsesSearchRequest | None = None,
+        includes: list[str] | None = None,
     ) -> DtoResponse[list[models.CMSResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
@@ -34,9 +36,8 @@ class CMSes(Resource):
                 "page": page,
                 "per_page": per_page,
             }
-            | include_filters.dict(exclude_unset=True)
-            if include_filters
-            else None,
+            | (include_filters.dict(exclude_unset=True) if include_filters else {})
+            | construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.CMSResource)
@@ -45,9 +46,13 @@ class CMSes(Resource):
         self,
         *,
         id_: int,
+        includes: list[str] | None = None,
     ) -> DtoResponse[models.CMSResource]:
         local_response = self.api_connector.send_or_fail(
-            "GET", f"/api/v1/cmses/{id_}", data=None, query_parameters={}
+            "GET",
+            f"/api/v1/cmses/{id_}",
+            data=None,
+            query_parameters=construct_includes_query_parameter(includes),
         )
 
         return DtoResponse.from_response(local_response, models.CMSResource)
